%define oname Ardour
%define maj %{expand:%(echo "%{version}" | cut -d. -f1)}

Name:    ardour
Epoch:   1
Version: 7.3.0
Release: %mkrel 1
Summary: Professional multi-track audio recording application
Group:   Sound/Editors and Converters
License: GPLv2+
URL:     https://ardour.org/

Source0: https://community.ardour.org/download/release/504#/%{oname}-%{version}.tar.bz2

BuildRequires: boost-devel
BuildRequires: dmalloc
BuildRequires: doxygen
BuildRequires: gettext
BuildRequires: graphviz
BuildRequires: gtk2-devel >= 2.12.1
BuildRequires: gtkmm2.4-devel >= 2.8
BuildRequires: pkgconfig(jack)
BuildRequires: readline-devel
BuildRequires: shared-mime-info
BuildRequires: xdg-utils
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(aubio) >= 0.3.2
BuildRequires: pkgconfig(cairo)
BuildRequires: pkgconfig(cairomm-1.0)
BuildRequires: pkgconfig(cppunit) >= 1.12.0
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(cwiid)
BuildRequires: pkgconfig(fftw3)
BuildRequires: pkgconfig(flac) >= 1.2.1
BuildRequires: pkgconfig(glib-2.0) >= 2.2
BuildRequires: pkgconfig(libarchive) >= 3.0.0
BuildRequires: pkgconfig(libart-2.0)
BuildRequires: pkgconfig(libcurl) >= 7.0.0
BuildRequires: pkgconfig(libgnomecanvas-2.0) >= 2.30
BuildRequires: pkgconfig(liblo) >= 0.24
BuildRequires: pkgconfig(libusb)
BuildRequires: pkgconfig(libusb-1.0)
BuildRequires: pkgconfig(libxslt)
BuildRequires: pkgconfig(lilv-0) >= 0.14
BuildRequires: pkgconfig(lrdf) >= 0.4.0
BuildRequires: pkgconfig(ltc) >= 1.1.0
BuildRequires: pkgconfig(lv2)
BuildRequires: pkgconfig(ogg) >= 1.1.2
BuildRequires: pkgconfig(python3)
BuildRequires: pkgconfig(raptor2)
BuildRequires: pkgconfig(redland)
BuildRequires: pkgconfig(rubberband)
BuildRequires: pkgconfig(samplerate)
BuildRequires: pkgconfig(serd-0) >= 0.14.0
BuildRequires: pkgconfig(sndfile) >= 1.0.18
BuildRequires: pkgconfig(sord-0) >= 0.8.0
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(sratom-0) >= 0.4.0
BuildRequires: pkgconfig(suil-0) >= 0.6.0
BuildRequires: pkgconfig(taglib)
BuildRequires: pkgconfig(uuid)
BuildRequires: pkgconfig(vamp-sdk)
BuildRequires: desktop-file-utils

Requires: jackit
Requires: gtk2-clearlooks-engine

#to ensure that all LV2 plugins will work properly:
Requires: suil-x11-in-gtk2

Obsoletes: %{name}3 < 4.0
Conflicts: %{name}3 < 4.0
Provides:  %{name}3 = %{version}-%{release}

%description
Ardour is a digital audio workstation. You can use it to record, edit and mix
multi-track audio and MIDI. You can produce your own CDs, mix video sound
tracks, or just experiment with new ideas about music and sound.

Ardour capabilities include: multi channel recording, non-destructive editing
with unlimited undo/redo, full automation support, LV2 and Linux VST plugins 
support, a powerful mixer, unlimited tracks/buses/plugins, time-code
synchronization, and hardware control from surfaces like the
Mackie Control Universal.

%prep
%setup -q -n %{oname}-%{version}

%build
export CFLAGS="%optflags"

%{__python3} ./waf configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --configdir=%{_sysconfdir} \
    --program-name=Ardour \
    --nls \
    --docs \
    --cxx11 \
    --optimize \
    --with-backends="jack,alsa,dummy " \
    --no-phone-home

%{__python3} ./waf build \
    --nls \
    --docs

%{__python3} ./waf i18n_mo

%install
%{__python3} ./waf install --destdir=%{buildroot}

# Symlink icons and mimetypes into the right folders
install -d -m 0755 %{buildroot}%{_iconsdir}

for i in 16 22 32 48; do
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes
ln -s %{_datadir}/%{name}%{maj}/icons/application-x-%{name}_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes/application-x-%{name}%{maj}.png
ln -s %{_datadir}/%{name}%{maj}/icons/application-x-%{name}_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}%{maj}.png
done

cat>%{name}.desktop<<EOF
[Desktop Entry]
Comment=Digital Audio Workstation
Comment[en_GB]=Digital Audio Workstation
Comment[ru_RU]=Программа звукозаписи
Exec=ardour%{maj}
GenericName=%{oname}
GenericName[en_GB]=%{oname}
Icon=%{name}%{maj}
MimeType=application/x-%{name};
Name=%{oname}
Name[en_GB]=%{oname}
StartupNotify=true
Terminal=false
Type=Application
Categories=AudioVideo;Audio;X-Recorders;X-Multitrack;X-Jack;X-Mageia-CrossDesktop;

EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}.desktop

cat > README.urpmi <<EOF
You will need to add yourself to the 'audio' and 'realtime' groups before using Ardour.
This may be done in a terminal by using the following commands:

su

gpasswd -a <yourusername> audio

gpasswd -a <yourusername> realtime

exit

You can alternatively do this by using the Mageia Control Center GUI:
System -> Manage Users on System -> Right click on your user, twice -> Edit -> Groups tab -> 
Check boxes for audio and realtime groups -> Click on OK

You will need to log out and log back in before using Ardour for the first time.

EOF

cp -a README.urpmi README.Mageia

%files
%doc README README.urpmi README.Mageia
%{_bindir}/%{name}%{maj}
%{_bindir}/%{name}%{maj}-lua
%{_libdir}/%{name}%{maj}
%{_datadir}/%{name}%{maj}
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/%{name}%{maj}
%{_iconsdir}/hicolor/*/*/*ardour7.png
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/%{name}.menus
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.ardoursans.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/default_ui_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/system_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/ardour.keys


%changelog
* Tue Feb 14 2023 kekepower <kekepower> 1:7.3.0-1.mga9
+ Revision: 1942388
- Update to version 7.3.0

* Sat Jan 28 2023 wally <wally> 1:7.2.0-2.mga9
+ Revision: 1936638
- don't own hicolor icon dirs

* Tue Dec 13 2022 kekepower <kekepower> 1:7.2.0-1.mga9
+ Revision: 1921490
- Update to version 7.2.0

* Sun Nov 20 2022 wally <wally> 1:7.1.0-2.mga9
+ Revision: 1909253
- rebuild for flac 1.4.2

* Thu Nov 03 2022 kekepower <kekepower> 1:7.1.0-1.mga9
+ Revision: 1902209
- Update to version 7.1.0

* Sun Oct 16 2022 kekepower <kekepower> 1:7.0-1.mga9
+ Revision: 1897101
- Update to version 7.0

* Sun Sep 25 2022 barjac <barjac> 1:6.9.0-4.mga9
+ Revision: 1892284
- revert change to clang and test build on all arches

* Sat Sep 24 2022 barjac <barjac> 1:6.9.0-3.mga9
+ Revision: 1892064
- restrict builds to 64bit arch

* Sat Sep 24 2022 barjac <barjac> 1:6.9.0-2.mga9
+ Revision: 1891984
- Exclude i586 from build
- fix build
+ kekepower <kekepower>
- Update to version 6.9.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Jun 24 2021 kekepower <kekepower> 1:6.7.0-1.mga9
+ Revision: 1732164
- Update to version 6.7.0
+ daviddavid <daviddavid>
- remove suil-qt4 dependencies

* Sun Oct 18 2020 barjac <barjac> 1:6.3.0-1.mga8
+ Revision: 1636682
- new version 6.3.0
- update Source0
- build with python3
- fix over long description lines
- fix files list

* Thu Feb 20 2020 umeabot <umeabot> 1:5.12.0-8.mga8
+ Revision: 1546960
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 luigiwalser <luigiwalser> 1:5.12.0-7.mga8
+ Revision: 1487341
- rebuild for readline
+ tv <tv>
- rebuild for new readline

* Thu May 02 2019 wally <wally> 1:5.12.0-5.mga7
+ Revision: 1396197
- require clearlooks gtk2 engine

* Fri Sep 21 2018 umeabot <umeabot> 1:5.12.0-4.mga7
+ Revision: 1294536
- Mageia 7 Mass Rebuild

* Sun Feb 11 2018 semiletov <semiletov> 1:5.12.0-3.mga7
+ Revision: 1200446
- recuired-libs has been added to ensure proper LV2-plugins loading; description fixes

* Sat Feb 03 2018 zezinho <zezinho> 1:5.12.0-2.mga7
+ Revision: 1198709
- rebuild against new vamp-plugins-sdk-2.7.1

* Sun Oct 22 2017 zezinho <zezinho> 1:5.12.0-1.mga7
+ Revision: 1173109
- new version

* Tue Aug 08 2017 daviddavid <daviddavid> 1:5.9.0-2.mga7
+ Revision: 1138908
- rebuild for new libaubio 0.4.5

* Wed May 17 2017 animtim <animtim> 1:5.9.0-1.mga6
+ Revision: 1102282
- update to 5.9.0
  add some configure options

* Mon Mar 06 2017 barjac <barjac> 1:5.8.0-1.mga6
+ Revision: 1088911
- new version 5.8.0

* Wed Dec 21 2016 barjac <barjac> 1:5.5.0-1.mga6
+ Revision: 1076253
- new version 5.5.0

* Wed Oct 19 2016 barjac <barjac> 1:5.4.0-1.mga6
+ Revision: 1062177
- new version 5.4.0
- new BuildRequires: pkgconfig(libarchive)

* Wed Sep 07 2016 barjac <barjac> 1:5.3.0-2.mga6
+ Revision: 1050289
- fix missing desktop icon

* Mon Sep 05 2016 barjac <barjac> 1:5.3.0-1.mga6
+ Revision: 1050041
- new release 5.3.0
- fix files list
- fix Note about Source0 now available without email

* Mon Mar 28 2016 neoclust <neoclust> 1:4.7.0-3.mga6
+ Revision: 996045
- Rebuild now that aubio is available on ARM

* Sun Feb 21 2016 barjac <barjac> 1:4.7.0-2.mga6
+ Revision: 975369
- rebuild for arm

* Sun Feb 21 2016 barjac <barjac> 1:4.7.0-1.mga6
+ Revision: 975280
- new version 4.7.0

* Fri Jan 15 2016 barjac <barjac> 1:4.6.0-2.mga6
+ Revision: 923197
- let users deal with groups
- added README.urpmi to explain how

* Thu Jan 14 2016 barjac <barjac> 1:4.6.0-1.mga6
+ Revision: 922945
- new version 4.6.0

* Thu Dec 17 2015 barjac <barjac> 1:4.4.0-1.mga6
+ Revision: 911525
- import package ardour

